Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Pipeline ¶
type Pipeline struct {
// contains filtered or unexported fields
}
Pipeline orchestrates the ingestion of markdown files into the ChromaDB store.
func NewPipeline ¶
NewPipeline creates an ingestion pipeline with the given number of concurrent workers.
Click to show internal directories.
Click to hide internal directories.